@extends ('layouts.patient')

@section('inner-content')

<script>
    window.userShortcuts = <?= json_encode($shortCutsObject); ?>;
</script>
<link href="/select2/select2.min.css" rel="stylesheet" />
<script src="/select2/select2.min.js"></script>
<div>

    {{-- CARE PLAN START --}}
    <?php $infoLines = json_decode($patient->info_lines); ?>
    <?php $infoLines = !$infoLines ? [] : $infoLines; ?>
    <?php $vitalLabels = ['Ht. (in.)', 'Wt. (lbs.)', 'Temp. (F)', 'Pulse', 'Resp.', 'Pulse Ox.', 'SBP', 'DBP', 'Smoking Status', 'BMI']; ?>
    <?php $isOldClient = (date_diff(date_create(config('app.point_impl_date')), date_create($patient->created_at))->invert === 1); ?>

    <div class="row client-single-dashboard">
        <div class="col-6">
            <?php
            $myCurrentClientReviewRequest = $pro->currentMonthClientReviewRequest($patient->id);
            ?>
            @if($myCurrentClientReviewRequest)
            <div class="pt-2 mt-2">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Client Review Request - {{ friendly_date(date('Y-m-01')) }}</h6>
                </div>
                @if($myCurrentClientReviewRequest->status === 'PENDING')
                <div class="alert alert-danger">
                    <div class="d-flex align-items-center justify-content-between">
                        <p class="mb-0">Please review this chart</p>
                        <div>
                            @include('app.patient.review-requests.partials.physician-update-status', ['record' =>$myCurrentClientReviewRequest ])
                        </div>
                    </div>
                </div>
                @endif
                @if($myCurrentClientReviewRequest->status === 'DONE')
                <div class="alert alert-success">
                    <div class="d-flex align-items-center justify-content-between">
                        <div>
                            <p class="mb-1">You have already reviewed this chart.</p>
                            @if($myCurrentClientReviewRequest->status_memo)
                            <div class="d-flex align-items-start">
                                <span class="mr-3"><i class="fas fa-calendar"></i> {{ friendly_date_time($myCurrentClientReviewRequest->status_updated_at) }}</span>
                                <small class="text-muted">{{ $myCurrentClientReviewRequest->status_memo }}
                                    @if(!$myCurrentClientReviewRequest->generic_bill_id)
                                        @include('app.patient.review-requests.partials.physician-update-status', ['record' =>$myCurrentClientReviewRequest, 'updateMemo' => true ])
                                    @endif
                                </small>
                            </div>

                            @endif
                        </div>
                        <div>
                            @if($myCurrentClientReviewRequest->generic_bill_id)
                            <button class="btn btn-sm btn-success"><i class="fas fa-check-circle"></i> Bill Submitted</button>
                            @else
                                @include('app.patient.review-requests.partials.physician-submit-client-review-bill', ['record' =>$myCurrentClientReviewRequest ])
                            @endif
                        </div>
                    </div>
                </div>
                @endif
            </div>
            @endif
            {{-- rpm summary for current caremonth --}}
            @if($patient->currentCareMonth() && $patient->currentCareMonth()->is_client_enrolled_in_rm)
                @include('app/patient/partials/caremonth-summary', ['careMonth' => $patient->currentCareMonth()])
            @endif

            {{-- appointments --}}
            @include('app/patient/partials/appointments')

            <?php $hasAllergiesInCanvas = $patient->hasDataInCanvas('allergies'); ?>

            {{-- canvas based allergies --}}
            @if($isOldClient && $hasAllergiesInCanvas)
            <div class="pt-2 mt-2 border-top">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Allergies</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.allergies.summary')
                </div>
            </div>
            @endif

            <!-- allergies - point -->
            @include('app.patient.point-based-partials.allergies')

            <?php $hasRxInCanvas = $patient->hasDataInCanvas('rx'); ?>

            {{-- canvas based rx --}}
            @if($isOldClient && $hasRxInCanvas)
            <div class="pt-2 mt-2 border-top">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Current Medications</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.rx.summary')
                </div>
            </div>
            @endif

            <!-- meds - point -->
            @include('app.patient.point-based-partials.rx')

            {{-- devices --}}
            <div class="mt-2 pb-1" id="patient-dashboard-devices">
                <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                    <h6 class="my-0 font-weight-bold">Devices</h6>
                    @if($availableDevices > 0 && $pro->pro_type === 'ADMIN')
                    <span class="mx-2 text-secondary">|</span>
                    <span moe>
                        <a start show>Add</a>
                        <form url="/api/clientBdtDevice/create" class="mcp-theme-1">
                            <input type="hidden" name="clientUid" value="{{$patient->uid}}">
                            <div class="mb-2">
                                <label class="text-secondary text-sm">Device</label>
                                <select name="deviceUid" class="form-control form-control-sm">
                                    <option value=""> --select-- </option>
                                    @foreach($devices as $device)
                                    @if(!in_array($device->id, $patientDeviceIDs))
                                    <option value="{{$device->uid}}">
                                        {{$device->imei}} ({{$device->category}})
                                    </option>
                                    @endif
                                    @endforeach
                                </select>
                            </div>
                            <div class="mb-2">
                                <label class="text-secondary text-sm">Instructions</label>
                                <input type="text" name="instructions" class="form-control form-control-sm">
                            </div>
                            <div class="mb-2">
                                <label class="text-secondary text-sm">Internal Memo</label>
                                <input type="text" name="internalMemo" class="form-control form-control-sm">
                            </div>
                            <div class="mb-2">
                                <label class="text-secondary text-sm">Status</label>
                                <input type="text" name="status" class="form-control form-control-sm">
                            </div>
                            <div class="mb-2">
                                <label class="text-secondary text-sm">Status Memo</label>
                                <input type="text" name="statusMemo" class="form-control form-control-sm">
                            </div>
                            <div>
                                <button submit class="btn btn-sm btn-primary mr-1">Submit</button>
                                <button cancel class="btn btn-sm btn-default border">Cancel</button>
                            </div>
                        </form>
                    </span>
                    @endif
                </div>
                <table class="table table-sm border-0 my-0 mx-2">
                    <tbody>
                        @foreach($patient->devices as $device)
                        <tr>
                            <td class="text-black p-0 border-0">
                                <div class="pb-0">
                                    <span relative moe>
                                        <a class="on-hover-opaque" start show title="Update">
                                            <i class="font-size-11 fa fa-edit text-primary"></i>
                                        </a>
                                        <form url="/api/clientBdtDevice/update">
                                            <input type="hidden" name="uid" value="{{ $device->uid }}">
                                            <div class="mb-2">
                                                <label class="text-secondary text-sm">Instructions</label>
                                                <input type="text" name="instructions" value="{{$device->instructions}}" class="form-control form-control-sm">
                                            </div>
                                            <div class="mb-2">
                                                <label class="text-secondary text-sm">Internal Memo</label>
                                                <input type="text" name="internalMemo" value="{{$device->internal_memo}}" class="form-control form-control-sm">
                                            </div>
                                            <div class="mb-2">
                                                <label class="text-secondary text-sm">Status</label>
                                                <input type="text" name="status" value="{{$device->status}}" class="form-control form-control-sm">
                                            </div>
                                            <div class="mb-2">
                                                <label class="text-secondary text-sm">Status Memo</label>
                                                <input type="text" name="statusMemo" value="{{$device->status_memo}}" class="form-control form-control-sm">
                                            </div>
                                            <div>
                                                <button submit class="btn btn-sm btn-primary mr-1">Submit</button>
                                                <button cancel class="btn btn-sm btn-default border">Cancel</button>
                                            </div>
                                        </form>
                                    </span>
                                    <b>{{$device->device->category}}</b>&nbsp;/&nbsp;IMEI: {{$device->device->imei}}
                                </div>
                            </td>
                        </tr>
                        @endforeach
                        @if(!$patient->devices || count($patient->devices) === 0)
                        <tr>
                            <td class="text-secondary p-0 border-0">
                                No devices
                            </td>
                        </tr>
                        @endif
                    </tbody>
                </table>
            </div>

            {{-- device measurements --}}
            {{-- @include('app/patient/partials/device-measurements') --}}

            {{-- measurements --}}
            @include('app/patient/partials/measurements')

            {{-- vitals --}}
            {{--@include('app/patient/partials/vitals')--}}

            <?php $hasVitalsInCanvas = $patient->hasDataInCanvas('vitals'); ?>

            {{-- canvas based vitals --}}
            @if($isOldClient && $hasVitalsInCanvas)
            <div class="pt-2 border-top">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Vitals</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.vitals.summary')
                </div>
            </div>
            @endif

            <!-- vitals - point -->
            <div class="pt-2 mt-2">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Vitals
                        @if(!!$latestVitals && $latestVitals->note && $latestVitals->note->effective_dateest)
                        <span class="text-secondary font-weight-normal pl-1">(as on
                            <a href="{{route('patients.view.notes.view.dashboard', ['patient' => $patient, 'note' => $latestVitals->note])}}">{{friendlier_date($latestVitals->note->effective_dateest)}}</a>)
                        </span>
                        @endif
                    </h6>
                    @if($isOldClient && $hasVitalsInCanvas)
                    <div class="px-2 font-weight-bold alert alert-info text-sm my-0 ml-2 py-1">New</div>
                    @endif
                </div>
                <div class="bg-light border p-2 mb-3">
                    @if(!!$latestVitals)
                    @include('app.patient.partials.latest-vitals', ['patient' => $patient, 'point' => $latestVitals])
                    @else
                    <div class="text-secondary">Nothing here yet</div>
                    @endif
                </div>
            </div>

        </div>
        <div class="col-6">

            <?php $hasDxInCanvas = $patient->hasDataInCanvas('dx'); ?>

            {{-- canvas based dx --}}
            @if($isOldClient)
            <div class="pt-2 mb-2 border-top">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Current Problems / Focus Areas</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.dx.summary')
                </div>
            </div>
            @endif

            <!-- probs - point -->
            @include('app.patient.point-based-partials.dx')

            <?php $hasCareTeamInCanvas = $patient->hasDataInCanvas('care-team'); ?>

            {{-- canvas based careteam --}}
            @if($isOldClient && $hasCareTeamInCanvas)
            <div class="pt-2 mt-2 border-top">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Care Team</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.care-team.summary')
                </div>
            </div>
            @endif

            <!-- careteam - point -->
            @include('app.patient.point-based-partials.care-team')

            <?php $hasPmhxInCanvas = $patient->hasDataInCanvas('pmhx'); ?>

            {{-- history_medical --}}
            @if($isOldClient && $hasPmhxInCanvas)
            <div class="pt-2 mt-2 border-top">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Medical History</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.pmhx.summary')
                </div>
            </div>
            @endif

            <!-- pmhx - point -->
            @include('app.patient.point-based-partials.pmhx')

            <?php $hasPshxInCanvas = $patient->hasDataInCanvas('pshx'); ?>

            {{-- history_surgical --}}
            @if($isOldClient && $hasPshxInCanvas)
            <div class="mt-2 border-top pt-2">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Surgical History</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.pshx.summary')
                </div>
            </div>
            @endif

            <!-- pshx - point -->
            @include('app.patient.point-based-partials.shx')

            <?php $hasFhxInCanvas = $patient->hasDataInCanvas('fhx'); ?>

            {{-- history_family --}}
            @if($isOldClient && $hasFhxInCanvas)
            <div class="mt-2 border-top pt-2">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Family History</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.fhx.summary')
                </div>
            </div>
            @endif

            <!-- fhx - point -->
            @include('app.patient.point-based-partials.fhx')

            <?php $hasSochxInCanvas = $patient->hasDataInCanvas('sochx'); ?>

            {{-- history_social --}}
            @if($isOldClient && $hasSochxInCanvas)
            <div class="mt-2 border-top pt-2">
                <div class="d-flex align-items-center pb-2">
                    <h6 class="my-0 font-weight-bold">Social History</h6>
                    <div class="px-2 font-weight-bold alert alert-warning text-sm my-0 ml-2 py-1">Deprecated</div>
                </div>
                <div class="bg-light border p-2 mb-3">
                    @include('app.patient.canvas-sections.sochx.summary')
                </div>
            </div>
            @endif

            <!-- sochx - point -->
            @include('app.patient.point-based-partials.sochx')


        </div>
    </div>

    <div class="row my-3">
        <div class="col-md-12">
            {{-- memos --}}
            @include('app.patient.partials.client-memos')
        </div>
    </div>

</div>
<script>
    (function() {
        function init() {
            $('select[name="deviceUid"]').select2({
                width: '100%'
            });

            // refresh once ticket popup is closed
            $('body').off('stag-popup-closed')
            /*$('body').on('stag-popup-closed', function() {
                if($('#client-rx-container').length) {
                    fastReload();
                }
            });*/
            // ticket-popup
            $(document)
                .off('click', '.ticket-popup-trigger')
                .on('click', '.ticket-popup-trigger', function() {
                    showMask();
                    window.noMc = true;
                    $.get(this.href, (_data) => {
                        $('.ticket-popup').html(_data);
                        showStagPopup('ticket-popup', true);
                        // $('.ticket-popup .stag-popup.stag-slide').attr('close-all-with-self', 1);
                        runMCInitializer('patient-tickets'); // run specific mc initer
                        hideMask();
                    });
                    return false;
                });

            addMCHook('onHxPopupClosure', function() {
                closeStagPopup();
            });

        }
        addMCInitializer('patient-dashboard-devices', init, '#patient-dashboard-devices');

    }).call(window);
</script>
@endsection